from django.views.generic import ListView, FormView

from .forms import FormExample
from .models import Task


class PaginatedList(ListView):
    template_name = 'showcase/paginated_list.html'
    model = Task
    paginate_by = 20


class FormExampleView(FormView):
    template_name = 'showcase/form.html'
    form_class = FormExample



import random
from django.db import migrations


def create_tasks(apps, schema_editor):
    Task = apps.get_model('showcase', 'Task')
    for number in range(1, 51):
        task = Task(
            name='Boring task name #{}'.format(number),
            done=random.randint(0, 1)
        )
        task.save()


def delete_tasks(apps, schema_editor):
    Task = apps.get_model('showcase', 'Task')
    Task.objects.all().delete()


class Migration(migrations.Migration):

    dependencies = [
        ('showcase', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_tasks, delete_tasks),
    ]



"""example URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.11/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.conf.urls import url, include
    2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
"""
from django.conf.urls import url, include
from django.contrib import admin
from django.views.generic import TemplateView
from django.contrib.auth.views import LoginView

urlpatterns = [
    url(r'^$', TemplateView.as_view(template_name='home.html')),
    url(r'^login/$', LoginView.as_view(), name='login'),
    url(r'^accounts/', include('allauth.urls')),
    url(r'^admin/', admin.site.urls),
    url(r'^showcase/', include('showcase.urls', namespace='showcase')),
]



from django.conf.urls import url

from . import views

app_name = 'showcase'
urlpatterns = [
    url(r'^list/$', views.PaginatedList.as_view(), name='paginated_list'),
    url(r'^form/$', views.FormExampleView.as_view(), name='form'),
]
